"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, privateMap, value) {
    if (!privateMap.has(receiver)) {
        throw new TypeError("attempted to set private field on non-instance");
    }
    privateMap.set(receiver, value);
    return value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, privateMap) {
    if (!privateMap.has(receiver)) {
        throw new TypeError("attempted to get private field on non-instance");
    }
    return privateMap.get(receiver);
};
var _ethers, _safeContract;
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
const constants_1 = require("../utils/constants");
class OwnerManager {
    constructor(ethers, safeContract) {
        _ethers.set(this, void 0);
        _safeContract.set(this, void 0);
        __classPrivateFieldSet(this, _ethers, ethers);
        __classPrivateFieldSet(this, _safeContract, safeContract);
    }
    validateOwnerAddress(ownerAddress, errorMessage) {
        const isValidAddress = __classPrivateFieldGet(this, _ethers).utils.isAddress(ownerAddress);
        if (!isValidAddress || utils_1.isRestrictedAddress(ownerAddress)) {
            throw new Error(errorMessage || 'Invalid owner address provided');
        }
    }
    validateThreshold(threshold, numOwners) {
        if (threshold <= 0) {
            throw new Error('Threshold needs to be greater than 0');
        }
        if (threshold > numOwners) {
            throw new Error('Threshold cannot exceed owner count');
        }
    }
    validateAddressIsNotOwner(ownerAddress, owners, errorMessage) {
        const ownerIndex = owners.findIndex((owner) => utils_1.sameString(owner, ownerAddress));
        const isOwner = ownerIndex >= 0;
        if (isOwner) {
            throw new Error(errorMessage || 'Address provided is already an owner');
        }
    }
    validateAddressIsOwner(ownerAddress, owners, errorMessage) {
        const ownerIndex = owners.findIndex((owner) => utils_1.sameString(owner, ownerAddress));
        const isOwner = ownerIndex >= 0;
        if (!isOwner) {
            throw new Error(errorMessage || 'Address provided is not an owner');
        }
        return ownerIndex;
    }
    async getOwners() {
        return __classPrivateFieldGet(this, _safeContract).getOwners();
    }
    async getThreshold() {
        return (await __classPrivateFieldGet(this, _safeContract).getThreshold()).toNumber();
    }
    async isOwner(ownerAddress) {
        return __classPrivateFieldGet(this, _safeContract).isOwner(ownerAddress);
    }
    async encodeAddOwnerWithThresholdData(ownerAddress, threshold) {
        this.validateOwnerAddress(ownerAddress);
        const owners = await this.getOwners();
        this.validateAddressIsNotOwner(ownerAddress, owners);
        const newThreshold = threshold !== null && threshold !== void 0 ? threshold : (await this.getThreshold());
        this.validateThreshold(newThreshold, owners.length);
        return __classPrivateFieldGet(this, _safeContract).interface.encodeFunctionData('addOwnerWithThreshold', [
            ownerAddress,
            newThreshold
        ]);
    }
    async encodeRemoveOwnerData(ownerAddress, threshold) {
        this.validateOwnerAddress(ownerAddress);
        const owners = await this.getOwners();
        const ownerIndex = this.validateAddressIsOwner(ownerAddress, owners);
        const newThreshold = threshold !== null && threshold !== void 0 ? threshold : (await this.getThreshold()) - 1;
        this.validateThreshold(newThreshold, owners.length - 1);
        const prevOwnerAddress = ownerIndex === 0 ? constants_1.SENTINEL_ADDRESS : owners[ownerIndex - 1];
        return __classPrivateFieldGet(this, _safeContract).interface.encodeFunctionData('removeOwner', [
            prevOwnerAddress,
            ownerAddress,
            newThreshold
        ]);
    }
    async encodeSwapOwnerData(oldOwnerAddress, newOwnerAddress) {
        this.validateOwnerAddress(newOwnerAddress, 'Invalid new owner address provided');
        this.validateOwnerAddress(oldOwnerAddress, 'Invalid old owner address provided');
        const owners = await this.getOwners();
        this.validateAddressIsNotOwner(newOwnerAddress, owners, 'New address provided is already an owner');
        const oldOwnerIndex = this.validateAddressIsOwner(oldOwnerAddress, owners, 'Old address provided is not an owner');
        const prevOwnerAddress = oldOwnerIndex === 0 ? constants_1.SENTINEL_ADDRESS : owners[oldOwnerIndex - 1];
        return __classPrivateFieldGet(this, _safeContract).interface.encodeFunctionData('swapOwner', [
            prevOwnerAddress,
            oldOwnerAddress,
            newOwnerAddress
        ]);
    }
    async encodeChangeThresholdData(threshold) {
        const owners = await this.getOwners();
        this.validateThreshold(threshold, owners.length);
        return __classPrivateFieldGet(this, _safeContract).interface.encodeFunctionData('changeThreshold', [threshold]);
    }
}
_ethers = new WeakMap(), _safeContract = new WeakMap();
exports.default = OwnerManager;
//# sourceMappingURL=ownerManager.js.map